@@ -6,7 +6,7 @@ import os
 from pathlib import Path
 from black import format_str, FileMode
 import edgedb
-from pydantic import BaseModel, parse_raw_as
+from pydantic import BaseModel, parse_raw_as, root_validator, ValidationError
 from devtools import debug
 from .introspection import (
     introspect_objects,
@@ -19,6 +19,8 @@ from .introspection import (
 )
 from .enums import PropertyCardinality
 
+ENV_VAR_PATTERN = r"[A-Z_]+"
+
 
 class DBVendor(str, Enum):
     edgedb = "edgedb"
@@ -43,14 +45,46 @@ class NodeConfig(BaseModel):
 
 class DBConfig(BaseModel):
     vendor: DBVendor
-    host: str
-    password: str
+    host: str = None
+    host_var: str = None
+    password: str = None
+    password_var: str = None
     port: int = 5656
     tls_security: TLSSecurity
     copy_config: str = None
     hydrate: bool = False
     nodes: T.Dict[str, NodeConfig] = dict()
 
+    @root_validator(pre=True)
+    def check_raw_or_vars(cls, values):
+        if values.get("host", None) is None:
+            if values.get("host_var", None) is None:
+                raise ValidationError("Must give either a host or a host_var")
+        if values.get("password", None) is None:
+            if values.get("password_var", None) is None:
+                raise ValidationError("Must give either a password or a password_var")
+        return values
+
+    @property
+    def password_val(self) -> str:
+        return self.password or os.environ[self.password_var]
+
+    @property
+    def host_val(self) -> str:
+        return self.host or os.environ[self.host_var]
+
+    @property
+    def password_variable(self) -> str:
+        return (
+            f'os.environ["{self.password_var}"]'
+            if self.password_var
+            else f'"{self.password}"'
+        )
+
+    @property
+    def host_variable(self) -> str:
+        return f'os.environ["{self.host_var}"]' if self.host_var else f'"{self.host}"'
+
 
 PATH_TO_MODULE = "edgedb_orm"
 DEFAULT_INDENT = "    "
@@ -69,6 +103,7 @@ def indent_lines(s: str, indent: str = DEFAULT_INDENT) -> str:
 def imports(enums_module: str) -> str:
     lines = [
         "from __future__ import annotations",
+        "import os",
         "import typing as T",
         "from enum import Enum",
         "from datetime import datetime, date, timedelta",
@@ -641,12 +676,18 @@ async def build_nodes_and_resolvers(
     return f"{nodes_str}\n\n{update_forward_refs_inserts_str}\n\n{update_forward_refs_nodes_str}\n\n{edge_resolver_map_str}"
 
 
+def add_quotes_to_non_env_vars(s: str) -> str:
+    if re.fullmatch(ENV_VAR_PATTERN, s) is not None:
+        return s
+    return f'"{s}"'
+
+
 def build_client(db_config: DBConfig) -> str:
     return f"""
 client = create_async_client(
-    tls_security="{db_config.tls_security.value}",
-    host="{db_config.host}",
-    password="{db_config.password}", 
+    tls_security={add_quotes_to_non_env_vars(db_config.tls_security.value)},
+    host={db_config.host_variable},
+    password={db_config.password_variable},
     port={db_config.port}
 )
     """
@@ -688,8 +729,8 @@ def get_nodes_to_hydrate(db_config: DBConfig) -> T.Set[str]:
 async def build_enums_from_config(db_config: DBConfig, include_strawberry: bool) -> str:
     client = edgedb.create_async_client(
         tls_security=db_config.tls_security,
-        host=db_config.host,
-        password=db_config.password,
+        host=db_config.host_val,
+        password=db_config.password_val,
         port=db_config.port,
     )
     enums_imports = build_enum_imports()
@@ -707,8 +748,8 @@ async def build_from_config(
 ) -> str:
     client = edgedb.create_async_client(
         tls_security=db_config.tls_security,
-        host=db_config.host,
-        password=db_config.password,
+        host=db_config.host_val,
+        password=db_config.password_val,
         port=db_config.port,
     )
     imports_str = imports(enums_module=enums_module)
